@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2012 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2013 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,8 +43,6 @@ static char *xml_files[] = {
 #endif
 };
 
-int debug = 0;
-
 int
 main (int argc, char *argv[])
 {
@@ -68,12 +66,12 @@ main (int argc, char *argv[])
 	  struct stat buf;
 	  if (stat (xml_files[i], &buf) != -1) {
 		  xml_file = xml_files[i];
-		  if (debug) printf ("Using interface file %s\n", xml_file);
+		  g_debug ("Using interface file %s\n", xml_file);
 		  break;
 	  }
   }
   if (! xml_file) {
-	  fprintf (stderr, _("Could not find interface definition file: %s"), "tenace.ui");
+	  fprintf (stderr, _("Could not find interface definition file: %s\n"), "tenace.ui");
 	  exit (1);
   }
 
@@ -111,6 +109,7 @@ main (int argc, char *argv[])
 		g_free (fname);
   } else {
 	board_window_append_board (win, NULL);
+	deal_random (win->boards[0]); /* show a random deal on startup */
   }
 
   show_board(win->boards[0], REDRAW_FULL);
